"""tests URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/3.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import path

from tests.test_app import views

urlpatterns = [
    path("admin/", admin.site.urls),
    path(
        "original/products/<int:pk>/",
        views.DRFProductRetrieveView.as_view(),
        name="product_retrieve_original",
    ),
    path(
        "service/products/",
        views.ProductListView.as_view(),
        name="product_list_service",
    ),
    path(
        "service/products/<int:pk>/",
        views.ProductRetrieveView.as_view(),
        name="product_retrieve_service",
    ),
    path(
        "errors/products/<int:pk>/",
        views.ErrorCaseView.as_view(),
        name="product_retrieve_errors",
    ),
]
